@@ -282,7 +282,7 @@ def time_ago(date):
     days_ago = (current_date - date).days
 
     if days_ago > 0: # More than 24 hours ago
-        return date.strftime('on %h %d, %Y at %I:%M%p Pacific')
+        return date.strftime('on %h %d, %Y at %I:%M%p')
 
     if hours_ago >= 1 and hours_ago <= 23: # An hour or more ago
         if hours_ago > 1:
